from __future__ import annotations

import os
from glob import glob

import importlib_resources
from tutor import hooks

from .__about__ import __version__

########################################
# CONFIGURATION
########################################

hooks.Filters.CONFIG_DEFAULTS.add_items(
    [
        # Add your new settings that have default values here.
        # Each new setting is a pair: (setting_name, default_value).
        # Prefix your setting names with 'SOCIAL_AUTH_MICHIGANONLINE_'.
        ("SOCIAL_AUTH_MICHIGANONLINE_VERSION", __version__),
        (
            "SOCIAL_AUTH_MICHIGANONLINE_REQUIREMENT_SPECIFIER",
            "social-auth-michiganonline==0.2.0b4",
        ),
        ("SOCIAL_AUTH_MICHIGANONLINE_INDEX_URL", "https://packages.ai.umich.edu"),
        ("SOCIAL_AUTH_MICHIGANONLINE_OAUTH_BASE_URL", ""),
    ]
)


########################################
# TEMPLATE RENDERING
# (It is safe & recommended to leave
#  this section as-is :)
########################################

hooks.Filters.ENV_TEMPLATE_ROOTS.add_items(
    # Root paths for template files, relative to the project root.
    [
        str(
            importlib_resources.files("tutor_social_auth_michiganonline") / "templates"
        ),
    ]
)

hooks.Filters.ENV_TEMPLATE_TARGETS.add_items(
    # For each pair (source_path, destination_path):
    # templates at ``source_path`` (relative to your ENV_TEMPLATE_ROOTS) will be
    # rendered to ``source_path/destination_path`` (relative to your Tutor environment).
    # For example, ``tutor_social_auth_michiganonline/templates/social-auth-michiganonline/build``
    # will be rendered to ``$(tutor config printroot)/env/plugins/social-auth-michiganonline/build``.
    [
        ("social-auth-michiganonline/build", "plugins"),
        ("social-auth-michiganonline/apps", "plugins"),
    ],
)


########################################
# PATCH LOADING
# (It is safe & recommended to leave
#  this section as-is :)
########################################

# For each file in tutor_social_auth_michiganonline/patches,
# apply a patch based on the file's name and contents.
for path in glob(
    str(importlib_resources.files("tutor_social_auth_michiganonline") / "patches" / "*")
):
    with open(path, encoding="utf-8") as patch_file:
        hooks.Filters.ENV_PATCHES.add_item((os.path.basename(path), patch_file.read()))
